@@ -1,4 +1,4 @@
-__version__ = '0.3.5'
+__version__ = '0.3.7'
 
 import random
 from termcolor import colored, cprint
@@ -7,6 +7,8 @@ import time
 from art import *
 import os
 import json
+import requests
+import urllib3
 pathToScript = os.path.dirname(os.path.abspath(__file__))
 
 
