@@ -4,11 +4,24 @@ import os
 import time
 import json
 import platform
-commands = {"Windows": ["cls", "exit"], "Linux":["clear", """
+import requests
+import urllib3
+
+def internet_on() ->bool:
+    url = "http://www.google.com"
+    timeout = 5
+    try:
+        request = requests.get(url, timeout=timeout)
+        return True
+    except (requests.ConnectionError, requests.Timeout) as exception:
+        return False
+
+
+commands = {"Windows": ["cls", "exit", "pip install Morpion --upgrade"], "Linux":["clear", """
         osascript -e 'tell application "Terminal" to close first window' && exit
-        """], "Darwin": ["clear", """
+        """, "pip3 install Morpion --upgrade"], "Darwin": ["clear", """
         osascript -e 'tell application "Terminal" to close first window' && exit
-        """] }
+        """, "pip3 install Morpion --upgrade"] }
 sys = platform.system()
 class variables():
     def __init__(self):
@@ -26,7 +39,8 @@ def loading():
     tprint("morpion")
     fill = colored('■', "blue")
     percent = 0
-    
+     
+     
 
     for progress in range(0, 1020):
         progress = progress/10
@@ -34,6 +48,8 @@ def loading():
         bar = f"Loading  [---------------------------------------------------] {percent} %" #11
         progress = loadFormat(progress)
         if progress!= 0:
+                
+                
             progress = int(progress/2)
             bar = bar.replace('-', fill, progress)
             print(f"{bar}", end="\r")
@@ -42,7 +58,11 @@ def loading():
         time.sleep(0.001)
     percent = 100
     bar = f"Loading  |{fill*50}| 100 %        "
+
     print(bar)
+    print('Checking for updates...')
+    if internet_on():
+        os.system(commands[sys][2])
     time.sleep(2)
     os.system(commands[sys][0])
 
@@ -61,11 +81,11 @@ def setGrid(turn, case, value) ->list:
     global grid3
     global grid4
     global grid5
-    grid1 = f"{cases[1]} | {cases[2]} | {cases[3]}"
-    grid2 = "--+---+--"
-    grid3 = f"{cases[4]} | {cases[5]} | {cases[6]}       tour {turn}"        
-    grid4 = "--+---+--"
-    grid5 = f"{cases[7]} | {cases[8]} | {cases[9]}"
+    grid1 = f"          {cases[1]} | {cases[2]} | {cases[3]}"
+    grid2 = "           --+---+--"
+    grid3 = f"          {cases[4]} | {cases[5]} | {cases[6]}       tour {turn}"        
+    grid4 = "           --+---+--"
+    grid5 = f"          {cases[7]} | {cases[8]} | {cases[9]}"
     return [grid1, grid2, grid3, grid4, grid5]
 
 
